Allure Pytest Plugin
====================
.. image:: https://pypip.in/v/allure-pytest/badge.png
        :alt: Release Status
        :target: https://pypi.python.org/pypi/allure-pytest
.. image:: https://pypip.in/d/allure-pytest/badge.png
        :alt: Downloads
        :target: https://pypi.python.org/pypi/allure-pytest

- `Source <https://github.com/allure-framework/allure-python>`_

- `Documentation <https://docs.qameta.io/allure/2.0/>`_

- `Gitter <https://gitter.im/allure-framework/allure-core>`_


Installation and Usage
======================

.. code:: bash

    $ pip install allure-pytest
    $ py.test --alluredir=%allure_result_folder% ./tests
    $ allure serve %allure_result_folder%
